Struct aws_sdk_iotdataplane::input::PublishInput [−][src]
#[non_exhaustive]pub struct PublishInput {
pub topic: Option<String>,
pub qos: i32,
pub retain: bool,
pub payload: Option<Blob>,
}Expand description
The input for the Publish operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.topic: Option<String>The name of the MQTT topic.
qos: i32The Quality of Service (QoS) level.
retain: boolA Boolean value that determines whether to set the RETAIN flag when the message is published.
Setting the RETAIN flag causes the message to be retained and sent to new subscribers to the topic.
Valid values: true | false
Default value: false
payload: Option<Blob>The message body. MQTT accepts text, binary, and empty (null) message payloads.
Publishing an empty (null) payload with retain =
true deletes the retained message identified by topic from IoT Core.
Implementations
pub fn make_operation(
self,
_config: &Config
) -> Result<Operation<Publish, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
self,
_config: &Config
) -> Result<Operation<Publish, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<Publish>
Creates a new builder-style object to manufacture PublishInput