#[non_exhaustive]pub struct GetConnectionInputBuilder { /* private fields */ }Expand description
A builder for GetConnectionInput.
Implementations
Sourceimpl GetConnectionInputBuilder
impl GetConnectionInputBuilder
Sourcepub fn client_id(self, input: impl Into<String>) -> Self
pub fn client_id(self, input: impl Into<String>) -> Self
The unique identifier of the MQTT client to retrieve connection information. The client ID can't start with a dollar sign ($).
MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters.
This field is required.Sourcepub fn set_client_id(self, input: Option<String>) -> Self
pub fn set_client_id(self, input: Option<String>) -> Self
The unique identifier of the MQTT client to retrieve connection information. The client ID can't start with a dollar sign ($).
MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters.
Sourcepub fn get_client_id(&self) -> &Option<String>
pub fn get_client_id(&self) -> &Option<String>
The unique identifier of the MQTT client to retrieve connection information. The client ID can't start with a dollar sign ($).
MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters.
Sourcepub fn include_socket_information(self, input: bool) -> Self
pub fn include_socket_information(self, input: bool) -> Self
Specifies if socket information (sourcePort, targetPort, sourceIp, targetIp) should be included in the GetConnection response. Set to TRUE to include socket information. Set to FALSE to omit socket information. By default, this is set to FALSE. See the developer guide for how to authorize this parameter.
Sourcepub fn set_include_socket_information(self, input: Option<bool>) -> Self
pub fn set_include_socket_information(self, input: Option<bool>) -> Self
Specifies if socket information (sourcePort, targetPort, sourceIp, targetIp) should be included in the GetConnection response. Set to TRUE to include socket information. Set to FALSE to omit socket information. By default, this is set to FALSE. See the developer guide for how to authorize this parameter.
Sourcepub fn get_include_socket_information(&self) -> &Option<bool>
pub fn get_include_socket_information(&self) -> &Option<bool>
Specifies if socket information (sourcePort, targetPort, sourceIp, targetIp) should be included in the GetConnection response. Set to TRUE to include socket information. Set to FALSE to omit socket information. By default, this is set to FALSE. See the developer guide for how to authorize this parameter.
Sourcepub fn build(self) -> Result<GetConnectionInput, BuildError>
pub fn build(self) -> Result<GetConnectionInput, BuildError>
Consumes the builder and constructs a GetConnectionInput.
Sourceimpl GetConnectionInputBuilder
impl GetConnectionInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetConnectionOutput, SdkError<GetConnectionError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetConnectionOutput, SdkError<GetConnectionError, HttpResponse>>
Sends a request with this input using the given client.