#[non_exhaustive]pub struct GetConnectionOutputBuilder { /* private fields */ }Expand description
A builder for GetConnectionOutput.
Implementations
Sourceimpl GetConnectionOutputBuilder
impl GetConnectionOutputBuilder
Sourcepub fn connected(self, input: bool) -> Self
pub fn connected(self, input: bool) -> Self
The connection state of the client. Returns true if the client is currently connected, or false if the client is not connected.
Sourcepub fn set_connected(self, input: Option<bool>) -> Self
pub fn set_connected(self, input: Option<bool>) -> Self
The connection state of the client. Returns true if the client is currently connected, or false if the client is not connected.
Sourcepub fn get_connected(&self) -> &Option<bool>
pub fn get_connected(&self) -> &Option<bool>
The connection state of the client. Returns true if the client is currently connected, or false if the client is not connected.
Sourcepub fn thing_name(self, input: impl Into<String>) -> Self
pub fn thing_name(self, input: impl Into<String>) -> Self
The name of the thing associated with the principal of the MQTT client, if applicable.
Sourcepub fn set_thing_name(self, input: Option<String>) -> Self
pub fn set_thing_name(self, input: Option<String>) -> Self
The name of the thing associated with the principal of the MQTT client, if applicable.
Sourcepub fn get_thing_name(&self) -> &Option<String>
pub fn get_thing_name(&self) -> &Option<String>
The name of the thing associated with the principal of the MQTT client, if applicable.
Sourcepub fn clean_session(self, input: bool) -> Self
pub fn clean_session(self, input: bool) -> Self
Indicates whether the client is using a clean session. Returns true for clean sessions or false for persistent sessions.
Sourcepub fn set_clean_session(self, input: Option<bool>) -> Self
pub fn set_clean_session(self, input: Option<bool>) -> Self
Indicates whether the client is using a clean session. Returns true for clean sessions or false for persistent sessions.
Sourcepub fn get_clean_session(&self) -> &Option<bool>
pub fn get_clean_session(&self) -> &Option<bool>
Indicates whether the client is using a clean session. Returns true for clean sessions or false for persistent sessions.
Sourcepub fn source_ip(self, input: impl Into<String>) -> Self
pub fn source_ip(self, input: impl Into<String>) -> Self
The IP address of the client that initiated the connection.
Sourcepub fn set_source_ip(self, input: Option<String>) -> Self
pub fn set_source_ip(self, input: Option<String>) -> Self
The IP address of the client that initiated the connection.
Sourcepub fn get_source_ip(&self) -> &Option<String>
pub fn get_source_ip(&self) -> &Option<String>
The IP address of the client that initiated the connection.
Sourcepub fn source_port(self, input: i32) -> Self
pub fn source_port(self, input: i32) -> Self
The client's source port.
Sourcepub fn set_source_port(self, input: Option<i32>) -> Self
pub fn set_source_port(self, input: Option<i32>) -> Self
The client's source port.
Sourcepub fn get_source_port(&self) -> &Option<i32>
pub fn get_source_port(&self) -> &Option<i32>
The client's source port.
Sourcepub fn target_ip(self, input: impl Into<String>) -> Self
pub fn target_ip(self, input: impl Into<String>) -> Self
The IP address of the Amazon Web Services IoT Core endpoint that the client connected to. For clients connected to VPC endpoints, this is the private IP address of the network interface the client is connected to.
Sourcepub fn set_target_ip(self, input: Option<String>) -> Self
pub fn set_target_ip(self, input: Option<String>) -> Self
The IP address of the Amazon Web Services IoT Core endpoint that the client connected to. For clients connected to VPC endpoints, this is the private IP address of the network interface the client is connected to.
Sourcepub fn get_target_ip(&self) -> &Option<String>
pub fn get_target_ip(&self) -> &Option<String>
The IP address of the Amazon Web Services IoT Core endpoint that the client connected to. For clients connected to VPC endpoints, this is the private IP address of the network interface the client is connected to.
Sourcepub fn target_port(self, input: i32) -> Self
pub fn target_port(self, input: i32) -> Self
The port number of the Amazon Web Services IoT Core endpoint that the client connected to.
Sourcepub fn set_target_port(self, input: Option<i32>) -> Self
pub fn set_target_port(self, input: Option<i32>) -> Self
The port number of the Amazon Web Services IoT Core endpoint that the client connected to.
Sourcepub fn get_target_port(&self) -> &Option<i32>
pub fn get_target_port(&self) -> &Option<i32>
The port number of the Amazon Web Services IoT Core endpoint that the client connected to.
Sourcepub fn keep_alive_duration(self, input: i32) -> Self
pub fn keep_alive_duration(self, input: i32) -> Self
The keep-alive interval in seconds that the client specified when establishing the connection.
Sourcepub fn set_keep_alive_duration(self, input: Option<i32>) -> Self
pub fn set_keep_alive_duration(self, input: Option<i32>) -> Self
The keep-alive interval in seconds that the client specified when establishing the connection.
Sourcepub fn get_keep_alive_duration(&self) -> &Option<i32>
pub fn get_keep_alive_duration(&self) -> &Option<i32>
The keep-alive interval in seconds that the client specified when establishing the connection.
Sourcepub fn connected_since(self, input: i64) -> Self
pub fn connected_since(self, input: i64) -> Self
Unix timestamp (in milliseconds) indicating when the client connected. Present only when connected is true.
Sourcepub fn set_connected_since(self, input: Option<i64>) -> Self
pub fn set_connected_since(self, input: Option<i64>) -> Self
Unix timestamp (in milliseconds) indicating when the client connected. Present only when connected is true.
Sourcepub fn get_connected_since(&self) -> &Option<i64>
pub fn get_connected_since(&self) -> &Option<i64>
Unix timestamp (in milliseconds) indicating when the client connected. Present only when connected is true.
Sourcepub fn disconnected_since(self, input: i64) -> Self
pub fn disconnected_since(self, input: i64) -> Self
Unix timestamp (in milliseconds) indicating when the client disconnected. Present only when connected is false. This information is available for 30 minutes after the client disconnects.
Sourcepub fn set_disconnected_since(self, input: Option<i64>) -> Self
pub fn set_disconnected_since(self, input: Option<i64>) -> Self
Unix timestamp (in milliseconds) indicating when the client disconnected. Present only when connected is false. This information is available for 30 minutes after the client disconnects.
Sourcepub fn get_disconnected_since(&self) -> &Option<i64>
pub fn get_disconnected_since(&self) -> &Option<i64>
Unix timestamp (in milliseconds) indicating when the client disconnected. Present only when connected is false. This information is available for 30 minutes after the client disconnects.
Sourcepub fn disconnect_reason(self, input: impl Into<String>) -> Self
pub fn disconnect_reason(self, input: impl Into<String>) -> Self
The reason for the last disconnection, if the client is currently disconnected. See the developer guide for valid disconnect reasons.
Sourcepub fn set_disconnect_reason(self, input: Option<String>) -> Self
pub fn set_disconnect_reason(self, input: Option<String>) -> Self
The reason for the last disconnection, if the client is currently disconnected. See the developer guide for valid disconnect reasons.
Sourcepub fn get_disconnect_reason(&self) -> &Option<String>
pub fn get_disconnect_reason(&self) -> &Option<String>
The reason for the last disconnection, if the client is currently disconnected. See the developer guide for valid disconnect reasons.
Sourcepub fn session_expiry(self, input: i64) -> Self
pub fn session_expiry(self, input: i64) -> Self
The session expiry interval in seconds for the MQTT client connection. This is configured by the user. This value indicates how long the session will remain active after the client disconnects.
Sourcepub fn set_session_expiry(self, input: Option<i64>) -> Self
pub fn set_session_expiry(self, input: Option<i64>) -> Self
The session expiry interval in seconds for the MQTT client connection. This is configured by the user. This value indicates how long the session will remain active after the client disconnects.
Sourcepub fn get_session_expiry(&self) -> &Option<i64>
pub fn get_session_expiry(&self) -> &Option<i64>
The session expiry interval in seconds for the MQTT client connection. This is configured by the user. This value indicates how long the session will remain active after the client disconnects.
Sourcepub fn client_id(self, input: impl Into<String>) -> Self
pub fn client_id(self, input: impl Into<String>) -> Self
The unique identifier of the MQTT client. This is the same client ID that was used when the client established the connection.
Sourcepub fn set_client_id(self, input: Option<String>) -> Self
pub fn set_client_id(self, input: Option<String>) -> Self
The unique identifier of the MQTT client. This is the same client ID that was used when the client established the connection.
Sourcepub fn get_client_id(&self) -> &Option<String>
pub fn get_client_id(&self) -> &Option<String>
The unique identifier of the MQTT client. This is the same client ID that was used when the client established the connection.
Sourcepub fn vpc_endpoint_id(self, input: impl Into<String>) -> Self
pub fn vpc_endpoint_id(self, input: impl Into<String>) -> Self
The ID of the VPC endpoint. Present for clients connected to IoT Core via a VPC endpoint.
Sourcepub fn set_vpc_endpoint_id(self, input: Option<String>) -> Self
pub fn set_vpc_endpoint_id(self, input: Option<String>) -> Self
The ID of the VPC endpoint. Present for clients connected to IoT Core via a VPC endpoint.
Sourcepub fn get_vpc_endpoint_id(&self) -> &Option<String>
pub fn get_vpc_endpoint_id(&self) -> &Option<String>
The ID of the VPC endpoint. Present for clients connected to IoT Core via a VPC endpoint.
Sourcepub fn build(self) -> GetConnectionOutput
pub fn build(self) -> GetConnectionOutput
Consumes the builder and constructs a GetConnectionOutput.