#[non_exhaustive]pub struct GetConnectionOutput {Show 14 fields
pub connected: bool,
pub thing_name: Option<String>,
pub clean_session: bool,
pub source_ip: Option<String>,
pub source_port: i32,
pub target_ip: Option<String>,
pub target_port: i32,
pub keep_alive_duration: i32,
pub connected_since: i64,
pub disconnected_since: i64,
pub disconnect_reason: Option<String>,
pub session_expiry: i64,
pub client_id: Option<String>,
pub vpc_endpoint_id: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connected: boolThe connection state of the client. Returns true if the client is currently connected, or false if the client is not connected.
thing_name: Option<String>The name of the thing associated with the principal of the MQTT client, if applicable.
clean_session: boolIndicates whether the client is using a clean session. Returns true for clean sessions or false for persistent sessions.
source_ip: Option<String>The IP address of the client that initiated the connection.
source_port: i32The client's source port.
target_ip: Option<String>The IP address of the Amazon Web Services IoT Core endpoint that the client connected to. For clients connected to VPC endpoints, this is the private IP address of the network interface the client is connected to.
target_port: i32The port number of the Amazon Web Services IoT Core endpoint that the client connected to.
keep_alive_duration: i32The keep-alive interval in seconds that the client specified when establishing the connection.
connected_since: i64Unix timestamp (in milliseconds) indicating when the client connected. Present only when connected is true.
disconnected_since: i64Unix timestamp (in milliseconds) indicating when the client disconnected. Present only when connected is false. This information is available for 30 minutes after the client disconnects.
disconnect_reason: Option<String>The reason for the last disconnection, if the client is currently disconnected. See the developer guide for valid disconnect reasons.
session_expiry: i64The session expiry interval in seconds for the MQTT client connection. This is configured by the user. This value indicates how long the session will remain active after the client disconnects.
client_id: Option<String>The unique identifier of the MQTT client. This is the same client ID that was used when the client established the connection.
vpc_endpoint_id: Option<String>The ID of the VPC endpoint. Present for clients connected to IoT Core via a VPC endpoint.
Implementations
Sourceimpl GetConnectionOutput
impl GetConnectionOutput
Sourcepub fn connected(&self) -> bool
pub fn connected(&self) -> bool
The connection state of the client. Returns true if the client is currently connected, or false if the client is not connected.
Sourcepub fn thing_name(&self) -> Option<&str>
pub fn thing_name(&self) -> Option<&str>
The name of the thing associated with the principal of the MQTT client, if applicable.
Sourcepub fn clean_session(&self) -> bool
pub fn clean_session(&self) -> bool
Indicates whether the client is using a clean session. Returns true for clean sessions or false for persistent sessions.
Sourcepub fn source_ip(&self) -> Option<&str>
pub fn source_ip(&self) -> Option<&str>
The IP address of the client that initiated the connection.
Sourcepub fn source_port(&self) -> i32
pub fn source_port(&self) -> i32
The client's source port.
Sourcepub fn target_ip(&self) -> Option<&str>
pub fn target_ip(&self) -> Option<&str>
The IP address of the Amazon Web Services IoT Core endpoint that the client connected to. For clients connected to VPC endpoints, this is the private IP address of the network interface the client is connected to.
Sourcepub fn target_port(&self) -> i32
pub fn target_port(&self) -> i32
The port number of the Amazon Web Services IoT Core endpoint that the client connected to.
Sourcepub fn keep_alive_duration(&self) -> i32
pub fn keep_alive_duration(&self) -> i32
The keep-alive interval in seconds that the client specified when establishing the connection.
Sourcepub fn connected_since(&self) -> i64
pub fn connected_since(&self) -> i64
Unix timestamp (in milliseconds) indicating when the client connected. Present only when connected is true.
Sourcepub fn disconnected_since(&self) -> i64
pub fn disconnected_since(&self) -> i64
Unix timestamp (in milliseconds) indicating when the client disconnected. Present only when connected is false. This information is available for 30 minutes after the client disconnects.
Sourcepub fn disconnect_reason(&self) -> Option<&str>
pub fn disconnect_reason(&self) -> Option<&str>
The reason for the last disconnection, if the client is currently disconnected. See the developer guide for valid disconnect reasons.
Sourcepub fn session_expiry(&self) -> i64
pub fn session_expiry(&self) -> i64
The session expiry interval in seconds for the MQTT client connection. This is configured by the user. This value indicates how long the session will remain active after the client disconnects.
Sourcepub fn client_id(&self) -> Option<&str>
pub fn client_id(&self) -> Option<&str>
The unique identifier of the MQTT client. This is the same client ID that was used when the client established the connection.
Sourcepub fn vpc_endpoint_id(&self) -> Option<&str>
pub fn vpc_endpoint_id(&self) -> Option<&str>
The ID of the VPC endpoint. Present for clients connected to IoT Core via a VPC endpoint.
Sourceimpl GetConnectionOutput
impl GetConnectionOutput
Sourcepub fn builder() -> GetConnectionOutputBuilder
pub fn builder() -> GetConnectionOutputBuilder
Creates a new builder-style object to manufacture GetConnectionOutput.