pub struct ListSubscriptionsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListSubscriptions.
Returns a list of all subscriptions for MQTT clients with active sessions, including offline clients with persistent sessions.
Requires permission to access the ListSubscriptions action.
Implementations
Sourceimpl ListSubscriptionsFluentBuilder
impl ListSubscriptionsFluentBuilder
Sourcepub fn as_input(&self) -> &ListSubscriptionsInputBuilder
pub fn as_input(&self) -> &ListSubscriptionsInputBuilder
Access the ListSubscriptions as a reference.
Sourcepub async fn send(
self,
) -> Result<ListSubscriptionsOutput, SdkError<ListSubscriptionsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListSubscriptionsOutput, SdkError<ListSubscriptionsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListSubscriptionsOutput, ListSubscriptionsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListSubscriptionsOutput, ListSubscriptionsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListSubscriptionsPaginator
pub fn into_paginator(self) -> ListSubscriptionsPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn client_id(self, input: impl Into<String>) -> Self
pub fn client_id(self, input: impl Into<String>) -> Self
The unique identifier of the MQTT client to list subscriptions for. The client ID can't start with a dollar sign ($).
MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters.
Sourcepub fn set_client_id(self, input: Option<String>) -> Self
pub fn set_client_id(self, input: Option<String>) -> Self
The unique identifier of the MQTT client to list subscriptions for. The client ID can't start with a dollar sign ($).
MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters.
Sourcepub fn get_client_id(&self) -> &Option<String>
pub fn get_client_id(&self) -> &Option<String>
The unique identifier of the MQTT client to list subscriptions for. The client ID can't start with a dollar sign ($).
MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of subscriptions to return in a single request. By default, this is set to 20.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of subscriptions to return in a single request. By default, this is set to 20.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of subscriptions to return in a single request. By default, this is set to 20.