#[non_exhaustive]pub struct ListSubscriptionsInputBuilder { /* private fields */ }Expand description
A builder for ListSubscriptionsInput.
Implementations
Sourceimpl ListSubscriptionsInputBuilder
impl ListSubscriptionsInputBuilder
Sourcepub fn client_id(self, input: impl Into<String>) -> Self
pub fn client_id(self, input: impl Into<String>) -> Self
The unique identifier of the MQTT client to list subscriptions for. The client ID can't start with a dollar sign ($).
MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters.
This field is required.Sourcepub fn set_client_id(self, input: Option<String>) -> Self
pub fn set_client_id(self, input: Option<String>) -> Self
The unique identifier of the MQTT client to list subscriptions for. The client ID can't start with a dollar sign ($).
MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters.
Sourcepub fn get_client_id(&self) -> &Option<String>
pub fn get_client_id(&self) -> &Option<String>
The unique identifier of the MQTT client to list subscriptions for. The client ID can't start with a dollar sign ($).
MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of subscriptions to return in a single request. By default, this is set to 20.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of subscriptions to return in a single request. By default, this is set to 20.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of subscriptions to return in a single request. By default, this is set to 20.
Sourcepub fn build(self) -> Result<ListSubscriptionsInput, BuildError>
pub fn build(self) -> Result<ListSubscriptionsInput, BuildError>
Consumes the builder and constructs a ListSubscriptionsInput.
Sourceimpl ListSubscriptionsInputBuilder
impl ListSubscriptionsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListSubscriptionsOutput, SdkError<ListSubscriptionsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListSubscriptionsOutput, SdkError<ListSubscriptionsError, HttpResponse>>
Sends a request with this input using the given client.