#[non_exhaustive]pub struct SendDirectMessageInputBuilder { /* private fields */ }Expand description
A builder for SendDirectMessageInput.
Implementations
Sourceimpl SendDirectMessageInputBuilder
impl SendDirectMessageInputBuilder
Sourcepub fn client_id(self, input: impl Into<String>) -> Self
pub fn client_id(self, input: impl Into<String>) -> Self
The unique identifier of the MQTT client to send the message to.
Client IDs must not exceed 128 characters and can't start with a dollar sign ($). MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
This field is required.Sourcepub fn set_client_id(self, input: Option<String>) -> Self
pub fn set_client_id(self, input: Option<String>) -> Self
The unique identifier of the MQTT client to send the message to.
Client IDs must not exceed 128 characters and can't start with a dollar sign ($). MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
Sourcepub fn get_client_id(&self) -> &Option<String>
pub fn get_client_id(&self) -> &Option<String>
The unique identifier of the MQTT client to send the message to.
Client IDs must not exceed 128 characters and can't start with a dollar sign ($). MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
Sourcepub fn topic(self, input: impl Into<String>) -> Self
pub fn topic(self, input: impl Into<String>) -> Self
The topic of the outbound MQTT Publish message to the receiving client. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
This field is required.Sourcepub fn set_topic(self, input: Option<String>) -> Self
pub fn set_topic(self, input: Option<String>) -> Self
The topic of the outbound MQTT Publish message to the receiving client. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
Sourcepub fn get_topic(&self) -> &Option<String>
pub fn get_topic(&self) -> &Option<String>
The topic of the outbound MQTT Publish message to the receiving client. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
Sourcepub fn content_type(self, input: impl Into<String>) -> Self
pub fn content_type(self, input: impl Into<String>) -> Self
The MQTT5 content type property forwarded to the receiving client (for example, application/json).
Sourcepub fn set_content_type(self, input: Option<String>) -> Self
pub fn set_content_type(self, input: Option<String>) -> Self
The MQTT5 content type property forwarded to the receiving client (for example, application/json).
Sourcepub fn get_content_type(&self) -> &Option<String>
pub fn get_content_type(&self) -> &Option<String>
The MQTT5 content type property forwarded to the receiving client (for example, application/json).
Sourcepub fn response_topic(self, input: impl Into<String>) -> Self
pub fn response_topic(self, input: impl Into<String>) -> Self
A UTF-8 encoded string that's used as the topic name for a response message. The response topic describes the topic which the receiver should publish to as part of the request-response flow. The topic must not contain wildcard characters. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
Sourcepub fn set_response_topic(self, input: Option<String>) -> Self
pub fn set_response_topic(self, input: Option<String>) -> Self
A UTF-8 encoded string that's used as the topic name for a response message. The response topic describes the topic which the receiver should publish to as part of the request-response flow. The topic must not contain wildcard characters. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
Sourcepub fn get_response_topic(&self) -> &Option<String>
pub fn get_response_topic(&self) -> &Option<String>
A UTF-8 encoded string that's used as the topic name for a response message. The response topic describes the topic which the receiver should publish to as part of the request-response flow. The topic must not contain wildcard characters. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
Sourcepub fn confirmation(self, input: bool) -> Self
pub fn confirmation(self, input: bool) -> Self
A Boolean value that specifies whether to wait for delivery confirmation from the receiving client.
When set to true, the API delivers the message at QoS 1 and waits for the client to send a delivery confirmation (PUBACK) before returning a successful response. If delivery confirmation is not received within the specified timeout period, the API returns HTTP 504.
When set to false, the API delivers the message at QoS 0 and returns after Amazon Web Services IoT Core attempts to deliver the message.
Valid values: true | false
Default value: false
Sourcepub fn set_confirmation(self, input: Option<bool>) -> Self
pub fn set_confirmation(self, input: Option<bool>) -> Self
A Boolean value that specifies whether to wait for delivery confirmation from the receiving client.
When set to true, the API delivers the message at QoS 1 and waits for the client to send a delivery confirmation (PUBACK) before returning a successful response. If delivery confirmation is not received within the specified timeout period, the API returns HTTP 504.
When set to false, the API delivers the message at QoS 0 and returns after Amazon Web Services IoT Core attempts to deliver the message.
Valid values: true | false
Default value: false
Sourcepub fn get_confirmation(&self) -> &Option<bool>
pub fn get_confirmation(&self) -> &Option<bool>
A Boolean value that specifies whether to wait for delivery confirmation from the receiving client.
When set to true, the API delivers the message at QoS 1 and waits for the client to send a delivery confirmation (PUBACK) before returning a successful response. If delivery confirmation is not received within the specified timeout period, the API returns HTTP 504.
When set to false, the API delivers the message at QoS 0 and returns after Amazon Web Services IoT Core attempts to deliver the message.
Valid values: true | false
Default value: false
Sourcepub fn timeout(self, input: i32) -> Self
pub fn timeout(self, input: i32) -> Self
An integer that represents the maximum time, in seconds, to wait for a delivery confirmation (PUBACK) from the receiving client after the message has been delivered. This parameter is only used when confirmation is set to true. If confirmation is false, this parameter is ignored.
The total API response time may be higher than this value due to internal processing. Set your HTTP client timeout to a value greater than this parameter.
Valid range: 1 to 15 seconds.
Default value: 5 seconds.
Sourcepub fn set_timeout(self, input: Option<i32>) -> Self
pub fn set_timeout(self, input: Option<i32>) -> Self
An integer that represents the maximum time, in seconds, to wait for a delivery confirmation (PUBACK) from the receiving client after the message has been delivered. This parameter is only used when confirmation is set to true. If confirmation is false, this parameter is ignored.
The total API response time may be higher than this value due to internal processing. Set your HTTP client timeout to a value greater than this parameter.
Valid range: 1 to 15 seconds.
Default value: 5 seconds.
Sourcepub fn get_timeout(&self) -> &Option<i32>
pub fn get_timeout(&self) -> &Option<i32>
An integer that represents the maximum time, in seconds, to wait for a delivery confirmation (PUBACK) from the receiving client after the message has been delivered. This parameter is only used when confirmation is set to true. If confirmation is false, this parameter is ignored.
The total API response time may be higher than this value due to internal processing. Set your HTTP client timeout to a value greater than this parameter.
Valid range: 1 to 15 seconds.
Default value: 5 seconds.
Sourcepub fn payload(self, input: Blob) -> Self
pub fn payload(self, input: Blob) -> Self
The message body. MQTT accepts text, binary, and empty (null) message payloads.
Sourcepub fn set_payload(self, input: Option<Blob>) -> Self
pub fn set_payload(self, input: Option<Blob>) -> Self
The message body. MQTT accepts text, binary, and empty (null) message payloads.
Sourcepub fn get_payload(&self) -> &Option<Blob>
pub fn get_payload(&self) -> &Option<Blob>
The message body. MQTT accepts text, binary, and empty (null) message payloads.
Sourcepub fn user_properties(self, input: impl Into<String>) -> Self
pub fn user_properties(self, input: impl Into<String>) -> Self
A JSON string that contains an array of JSON objects. If you don't use Amazon Web Services SDK or CLI, you must encode the JSON string to base64 format before adding it to the HTTP header. userProperties is an HTTP header value in the API.
For MQTT 3.1.1 clients, user properties are silently dropped.
The following example userProperties parameter is a JSON string which represents two User Properties. Note that it needs to be base64-encoded:
\[{"deviceName": "alpha"}, {"deviceCnt": "45"}\]
Sourcepub fn set_user_properties(self, input: Option<String>) -> Self
pub fn set_user_properties(self, input: Option<String>) -> Self
A JSON string that contains an array of JSON objects. If you don't use Amazon Web Services SDK or CLI, you must encode the JSON string to base64 format before adding it to the HTTP header. userProperties is an HTTP header value in the API.
For MQTT 3.1.1 clients, user properties are silently dropped.
The following example userProperties parameter is a JSON string which represents two User Properties. Note that it needs to be base64-encoded:
\[{"deviceName": "alpha"}, {"deviceCnt": "45"}\]
Sourcepub fn get_user_properties(&self) -> &Option<String>
pub fn get_user_properties(&self) -> &Option<String>
A JSON string that contains an array of JSON objects. If you don't use Amazon Web Services SDK or CLI, you must encode the JSON string to base64 format before adding it to the HTTP header. userProperties is an HTTP header value in the API.
For MQTT 3.1.1 clients, user properties are silently dropped.
The following example userProperties parameter is a JSON string which represents two User Properties. Note that it needs to be base64-encoded:
\[{"deviceName": "alpha"}, {"deviceCnt": "45"}\]
Sourcepub fn payload_format_indicator(self, input: PayloadFormatIndicator) -> Self
pub fn payload_format_indicator(self, input: PayloadFormatIndicator) -> Self
An Enum string value that indicates whether the payload is formatted as UTF-8. payloadFormatIndicator is an HTTP header value in the API.
Sourcepub fn set_payload_format_indicator(
self,
input: Option<PayloadFormatIndicator>,
) -> Self
pub fn set_payload_format_indicator( self, input: Option<PayloadFormatIndicator>, ) -> Self
An Enum string value that indicates whether the payload is formatted as UTF-8. payloadFormatIndicator is an HTTP header value in the API.
Sourcepub fn get_payload_format_indicator(&self) -> &Option<PayloadFormatIndicator>
pub fn get_payload_format_indicator(&self) -> &Option<PayloadFormatIndicator>
An Enum string value that indicates whether the payload is formatted as UTF-8. payloadFormatIndicator is an HTTP header value in the API.
Sourcepub fn correlation_data(self, input: impl Into<String>) -> Self
pub fn correlation_data(self, input: impl Into<String>) -> Self
The base64-encoded binary data used by the sender of the request message to identify which request the response message is for when it's received. correlationData is an HTTP header value in the API.
Sourcepub fn set_correlation_data(self, input: Option<String>) -> Self
pub fn set_correlation_data(self, input: Option<String>) -> Self
The base64-encoded binary data used by the sender of the request message to identify which request the response message is for when it's received. correlationData is an HTTP header value in the API.
Sourcepub fn get_correlation_data(&self) -> &Option<String>
pub fn get_correlation_data(&self) -> &Option<String>
The base64-encoded binary data used by the sender of the request message to identify which request the response message is for when it's received. correlationData is an HTTP header value in the API.
Sourcepub fn build(self) -> Result<SendDirectMessageInput, BuildError>
pub fn build(self) -> Result<SendDirectMessageInput, BuildError>
Consumes the builder and constructs a SendDirectMessageInput.
Sourceimpl SendDirectMessageInputBuilder
impl SendDirectMessageInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<SendDirectMessageOutput, SdkError<SendDirectMessageError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<SendDirectMessageOutput, SdkError<SendDirectMessageError, HttpResponse>>
Sends a request with this input using the given client.