#[non_exhaustive]pub struct SendDirectMessageInput {
pub client_id: Option<String>,
pub topic: Option<String>,
pub content_type: Option<String>,
pub response_topic: Option<String>,
pub confirmation: Option<bool>,
pub timeout: Option<i32>,
pub payload: Option<Blob>,
pub user_properties: Option<String>,
pub payload_format_indicator: Option<PayloadFormatIndicator>,
pub correlation_data: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_id: Option<String>The unique identifier of the MQTT client to send the message to.
Client IDs must not exceed 128 characters and can't start with a dollar sign ($). MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
topic: Option<String>The topic of the outbound MQTT Publish message to the receiving client. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
content_type: Option<String>The MQTT5 content type property forwarded to the receiving client (for example, application/json).
response_topic: Option<String>A UTF-8 encoded string that's used as the topic name for a response message. The response topic describes the topic which the receiver should publish to as part of the request-response flow. The topic must not contain wildcard characters. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
confirmation: Option<bool>A Boolean value that specifies whether to wait for delivery confirmation from the receiving client.
When set to true, the API delivers the message at QoS 1 and waits for the client to send a delivery confirmation (PUBACK) before returning a successful response. If delivery confirmation is not received within the specified timeout period, the API returns HTTP 504.
When set to false, the API delivers the message at QoS 0 and returns after Amazon Web Services IoT Core attempts to deliver the message.
Valid values: true | false
Default value: false
timeout: Option<i32>An integer that represents the maximum time, in seconds, to wait for a delivery confirmation (PUBACK) from the receiving client after the message has been delivered. This parameter is only used when confirmation is set to true. If confirmation is false, this parameter is ignored.
The total API response time may be higher than this value due to internal processing. Set your HTTP client timeout to a value greater than this parameter.
Valid range: 1 to 15 seconds.
Default value: 5 seconds.
payload: Option<Blob>The message body. MQTT accepts text, binary, and empty (null) message payloads.
user_properties: Option<String>A JSON string that contains an array of JSON objects. If you don't use Amazon Web Services SDK or CLI, you must encode the JSON string to base64 format before adding it to the HTTP header. userProperties is an HTTP header value in the API.
For MQTT 3.1.1 clients, user properties are silently dropped.
The following example userProperties parameter is a JSON string which represents two User Properties. Note that it needs to be base64-encoded:
\[{"deviceName": "alpha"}, {"deviceCnt": "45"}\]
payload_format_indicator: Option<PayloadFormatIndicator>An Enum string value that indicates whether the payload is formatted as UTF-8. payloadFormatIndicator is an HTTP header value in the API.
correlation_data: Option<String>The base64-encoded binary data used by the sender of the request message to identify which request the response message is for when it's received. correlationData is an HTTP header value in the API.
Implementations
Sourceimpl SendDirectMessageInput
impl SendDirectMessageInput
Sourcepub fn client_id(&self) -> Option<&str>
pub fn client_id(&self) -> Option<&str>
The unique identifier of the MQTT client to send the message to.
Client IDs must not exceed 128 characters and can't start with a dollar sign ($). MQTT client IDs must be URL encoded (percent-encoded) when they contain characters that are not valid in HTTP requests, such as spaces, forward slashes (/), and UTF-8 characters. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
Sourcepub fn topic(&self) -> Option<&str>
pub fn topic(&self) -> Option<&str>
The topic of the outbound MQTT Publish message to the receiving client. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
Sourcepub fn content_type(&self) -> Option<&str>
pub fn content_type(&self) -> Option<&str>
The MQTT5 content type property forwarded to the receiving client (for example, application/json).
Sourcepub fn response_topic(&self) -> Option<&str>
pub fn response_topic(&self) -> Option<&str>
A UTF-8 encoded string that's used as the topic name for a response message. The response topic describes the topic which the receiver should publish to as part of the request-response flow. The topic must not contain wildcard characters. For more information, see Amazon Web Services IoT Core message broker and protocol limits and quotas.
Sourcepub fn confirmation(&self) -> Option<bool>
pub fn confirmation(&self) -> Option<bool>
A Boolean value that specifies whether to wait for delivery confirmation from the receiving client.
When set to true, the API delivers the message at QoS 1 and waits for the client to send a delivery confirmation (PUBACK) before returning a successful response. If delivery confirmation is not received within the specified timeout period, the API returns HTTP 504.
When set to false, the API delivers the message at QoS 0 and returns after Amazon Web Services IoT Core attempts to deliver the message.
Valid values: true | false
Default value: false
Sourcepub fn timeout(&self) -> Option<i32>
pub fn timeout(&self) -> Option<i32>
An integer that represents the maximum time, in seconds, to wait for a delivery confirmation (PUBACK) from the receiving client after the message has been delivered. This parameter is only used when confirmation is set to true. If confirmation is false, this parameter is ignored.
The total API response time may be higher than this value due to internal processing. Set your HTTP client timeout to a value greater than this parameter.
Valid range: 1 to 15 seconds.
Default value: 5 seconds.
Sourcepub fn payload(&self) -> Option<&Blob>
pub fn payload(&self) -> Option<&Blob>
The message body. MQTT accepts text, binary, and empty (null) message payloads.
Sourcepub fn user_properties(&self) -> Option<&str>
pub fn user_properties(&self) -> Option<&str>
A JSON string that contains an array of JSON objects. If you don't use Amazon Web Services SDK or CLI, you must encode the JSON string to base64 format before adding it to the HTTP header. userProperties is an HTTP header value in the API.
For MQTT 3.1.1 clients, user properties are silently dropped.
The following example userProperties parameter is a JSON string which represents two User Properties. Note that it needs to be base64-encoded:
\[{"deviceName": "alpha"}, {"deviceCnt": "45"}\]
Sourcepub fn payload_format_indicator(&self) -> Option<&PayloadFormatIndicator>
pub fn payload_format_indicator(&self) -> Option<&PayloadFormatIndicator>
An Enum string value that indicates whether the payload is formatted as UTF-8. payloadFormatIndicator is an HTTP header value in the API.
Sourcepub fn correlation_data(&self) -> Option<&str>
pub fn correlation_data(&self) -> Option<&str>
The base64-encoded binary data used by the sender of the request message to identify which request the response message is for when it's received. correlationData is an HTTP header value in the API.
Sourceimpl SendDirectMessageInput
impl SendDirectMessageInput
Sourcepub fn builder() -> SendDirectMessageInputBuilder
pub fn builder() -> SendDirectMessageInputBuilder
Creates a new builder-style object to manufacture SendDirectMessageInput.