#[non_exhaustive]pub struct SendDirectMessageOutput {
pub message: Option<String>,
pub trace_id: Option<String>,
/* private fields */
}Expand description
The output from the SendDirectMessage operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: Option<String>The status message indicating the result of the operation.
trace_id: Option<String>A unique identifier for the request. Include this value when contacting Amazon Web Services Support for troubleshooting.
Implementations
Sourceimpl SendDirectMessageOutput
impl SendDirectMessageOutput
Sourcepub fn builder() -> SendDirectMessageOutputBuilder
pub fn builder() -> SendDirectMessageOutputBuilder
Creates a new builder-style object to manufacture SendDirectMessageOutput.