#[non_exhaustive]pub struct SubscriptionSummaryBuilder { /* private fields */ }Expand description
A builder for SubscriptionSummary.
Implementations
Sourceimpl SubscriptionSummaryBuilder
impl SubscriptionSummaryBuilder
Sourcepub fn topic_filter(self, input: impl Into<String>) -> Self
pub fn topic_filter(self, input: impl Into<String>) -> Self
The topic filter pattern that the client is subscribed to. May include MQTT wildcards such as + (single-level) and # (multi-level).
This field is required.Sourcepub fn set_topic_filter(self, input: Option<String>) -> Self
pub fn set_topic_filter(self, input: Option<String>) -> Self
The topic filter pattern that the client is subscribed to. May include MQTT wildcards such as + (single-level) and # (multi-level).
Sourcepub fn get_topic_filter(&self) -> &Option<String>
pub fn get_topic_filter(&self) -> &Option<String>
The topic filter pattern that the client is subscribed to. May include MQTT wildcards such as + (single-level) and # (multi-level).
Sourcepub fn qos(self, input: i32) -> Self
pub fn qos(self, input: i32) -> Self
The Quality of Service (QoS) level for the subscription. Valid values are 0 (at most once) and 1 (at least once).
This field is required.Sourcepub fn set_qos(self, input: Option<i32>) -> Self
pub fn set_qos(self, input: Option<i32>) -> Self
The Quality of Service (QoS) level for the subscription. Valid values are 0 (at most once) and 1 (at least once).
Sourcepub fn get_qos(&self) -> &Option<i32>
pub fn get_qos(&self) -> &Option<i32>
The Quality of Service (QoS) level for the subscription. Valid values are 0 (at most once) and 1 (at least once).
Sourcepub fn build(self) -> Result<SubscriptionSummary, BuildError>
pub fn build(self) -> Result<SubscriptionSummary, BuildError>
Consumes the builder and constructs a SubscriptionSummary.
This method will fail if any of the following fields are not set: